@@ -116,18 +116,6 @@ sub run {
         $env->{PATH_INFO} = uri_unescape($uri->path);
         $env->{PATH_INFO} =~ s/^\Q$env->{SCRIPT_NAME}\E//;
 
-        if ($env->{SERVER_SOFTWARE} && $env->{SERVER_SOFTWARE} =~ m!lighttpd[-/]1\.(\d+\.\d+)!) {
-            no warnings;
-            if ($ENV{PLACK_ENV} eq 'development' && $1 < 4.23 && $env->{PATH_INFO} eq '') {
-                warn "You're using lighttpd 1.$1 and appear to mount your FastCGI handler under the root ('/'). ",
-                     "It's known to be causing issues because of the lighttpd bug. You're recommended to enable ",
-                     "LighttpdScriptNameFix middleware, or upgrade lighttpd to 1.4.23 or later and include ",
-                     "'fix-root-scriptname' flag in 'fastcgi.server'. See perldoc Plack::Handler::FCGI for details. ",
-                     "This friendly warning will go away in the next major release of Plack.";
-            }
-            $env->{SERVER_NAME} =~ s/:\d+$//; # cut off port number
-        }
-
         # root access for mod_fastcgi
         if (!exists $env->{PATH_INFO}) {
             $env->{PATH_INFO} = '';
